@@ -49,7 +49,7 @@ MODULE_PARM( irq, "i" );
 #define BmDrvDevName "bmdrv" //the name of this device (max. 31 chars allowed)
 #define BmDrvDevId ((void *)(('b'<<24)+('m'<<16)+('d'<<8)+'r')) //the id of this device
 #define BmDrvDevVerMaj 1 //version of this device
-#define BmDrvDevVerMin 0
+#define BmDrvDevVerMin 1
 #define BmDrvDevVerRev 0
 
 //global types
@@ -293,7 +293,9 @@ void BmDrvButtonsIn( struct tBmDrvInternalControllerButtons * pButtonHyst )
 	for( Btn = 0; Btn < BmDrvInternalButtonCnt; Btn++ )
 	{
 		//read in this button of all controllers
-		Val = inb( BmDrvIoAddr + 1 );
+		Val = inb( BmDrvIoAddr + 1 ); //read in 3 times
+		Val = inb( BmDrvIoAddr + 1 ); //to give pad time
+		Val = inb( BmDrvIoAddr + 1 ); //to output data
 		//only interested in: nERROR, SELECT, PPROUT, -BUSY
 		Val &= 0xB8;
 		//-BUSY has got inverted hardware, but our buttons are active low
